@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8 -*-
+"""
+Quick and Easy Infrastructure
+"""
 
 from appdirs import *
 from pathlib import Path
@@ -12,6 +15,8 @@ ROOT_DIR = os.path.abspath(os.path.dirname(__file__))
 APP_NAME = "tempor"
 APP_AUTHOR = "wh1t3fox"
 
+with open(os.path.join(os.path.dirname(__file__), "VERSION")) as fr:
+    __version__ = fr.read().strip()
 
 CONFIG_DIR = user_config_dir(APP_NAME)
 DATA_DIR = user_data_dir(APP_NAME, APP_AUTHOR)
